#! /bin/bash

# Author: Francesco Visin
# 
# This script will create a 'package_filename'.launch and a launcher file. The first is a standard ros launch file, the second one is another bash script that will setup the environment and then perform the operations necessary to launch the package in gazebo.
# NOTE: The script has to be copied insied the package folder before being executed.
# Please set the following variable to the name of the package, before executing this script
package_filename="animate_joints"


# creating launch file
echo \
"<launch>

  <arg name="paused" default="false"/>
  <arg name="use_sim_time" default="true"/>
  <arg name="gui" default="true"/>
  <arg name="throttled" default="false"/>

  <!-- set use_sim_time flag -->
  <group if="$(arg use_sim_time)">
    <param name="/use_sim_time" value="true" />
  </group>


  <!-- start empty world -->
  <group if="$(arg paused)">
    <group if="$(arg throttled)">
      <node name="gazebo" pkg="gazebo" type="gazebo" args="-u `pwd`/`echo $package_filename`.world" respawn="false" output="screen"/>
    </group>
    <group unless="$(arg throttled)">
      <node name="gazebo" pkg="gazebo" type="gazebo" args="-u `pwd`/`echo $package_filename`.world" respawn="false" output="screen"/>
    </group>
  </group>
  <group unless="$(arg paused)">
    <group if="$(arg throttled)">
      <node name="gazebo" pkg="gazebo" type="gazebo" args="`pwd`/`echo $package_filename`.world" respawn="false" output="screen"/>
    </group>
    <group unless="$(arg throttled)">
      <node name="gazebo" pkg="gazebo" type="gazebo" args="`pwd`/`echo $package_filename`.world" respawn="false" output="screen"/>
    </group>
  </group>

  <!-- start gui -->
  <group if="$(arg gui)">
    <node name="gazebo_gui" pkg="gazebo" type="gui" respawn="false" output="screen"/>
  </group>

</launch>" \
 > `echo $package_filename`.launch



# creating launcher
echo \
"#! /bin/bash

export ROS_PACKAGE_PATH=\`pwd\`:\$ROS_PACKAGE_PATH
export GAZEBO_PLUGIN_PATH=\`pwd\`/build:\$GAZEBO_PLUGIN_PATH

gnome-terminal \\
--tab --title='ROSCORE' -e \"bash -c \\\"echo 'roscore'; export ROS_PACKAGE_PATH=\`pwd\`:\$ROS_PACKAGE_PATH; roscore; exec bash\\\"\" \\
\\
--tab --title='GAZEBO' -e \"bash -c \\\"echo 'rosrun gazebo gazebo control_model.world'; echo 'waiting for roscore...'; sleep 7; export ROS_PACKAGE_PATH=\`pwd\`:\$ROS_PACKAGE_PATH; echo \$ROS_PACKAGE_PATH; export GAZEBO_PLUGIN_PATH=\`pwd\`/build:\$GAZEBO_PLUGIN_PATH; roslaunch control_model.launch ; exec bash\\\"\"

exit" > launcher